==> pas-0.2.0-beta%2B1.21.2-sources.jar: com/danrus/render/ASCapeFeatureRenderer.java <==
package com.danrus.render;

import com.danrus.utils.PASModelData;
import com.danrus.utils.StringUtils;
import com.danrus.utils.interfaces.ModelWithCape;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_548;
import net.minecraft.class_7833;
import net.minecraft.class_9998;

//? if >=1.21.2 {
public class ASCapeFeatureRenderer extends class_3887<class_9998, class_548> {
    public ASCapeFeatureRenderer(class_3883<class_9998, class_548> context) {
//?} else {
/*public class ASCapeFeatureRenderer extends FeatureRenderer<ArmorStandEntity , ArmorStandArmorEntityModel> {
    public ASCapeFeatureRenderer(FeatureRendererContext<ArmorStandEntity, ArmorStandArmorEntityModel> context) {
*///?}
        super(context);
    }

    //? if >=1.21.2 {
    @Override
    public void render(class_4587 matrixStack, class_4597 vertexConsumers, int light, class_9998 state, float limbAngle, float limbDistance) {
        if (!state.field_53333 && state.field_53464 != null) {
            if (this.method_17165() instanceof ModelWithCape model) {
                var customName = state.field_53464;
                boolean isBaby = state.field_53457;


    //?} else {
    /*@Override
    public void render(MatrixStack matrixStack, VertexConsumerProvider vertexConsumers, int light, ArmorStandEntity entity, float limbAngle, float limbDistance, float tickDelta, float animationProgress, float headYaw, float headPitch) {
        if (!entity.isInvisible() && entity.getCustomName() != null) {
            if (this.getContextModel() instanceof ModelWithCape model) {
                var customName = entity.getCustomName();
                boolean isBaby = entity.isBaby();
    *///?}
                if (customName != null && StringUtils.matchASName(customName.getString()).get(1).contains("C")) {
                    PASModelData modelData = PASModelData.getByName(customName.getString());
                    class_2960 capeTexture = modelData.cape;

                    matrixStack.method_22903();
                    matrixStack.method_22907(class_7833.field_40714.rotationDegrees(10.0F));
                    matrixStack.method_22907(class_7833.field_40716.rotationDegrees(180F));
                    matrixStack.method_46416(0.0F, 0.02F, -0.12F);
                    if (isBaby) {
                        matrixStack.method_46416(0.0F, 0.7F, 0.2F);
                        matrixStack.method_22905(0.5F, 0.5F, 0.5F);
                    } else {
                        matrixStack.method_22905(1.0F, 1.0F, 1.0F);
                    }

                    class_4588 vertexConsumer = vertexConsumers.getBuffer(class_1921.method_23572(capeTexture));
                    model.getCape().field_3665 = true;
                    model.getCape().method_22698(matrixStack, vertexConsumer, light, class_4608.field_21444);

                    matrixStack.method_22909();
                }

            }
        }

    }
}

==> pas-0.2.2-beta%2B1.21.6-sources.jar: com/danrus/render/ASCapeFeatureRenderer.java <==
package com.danrus.render;

import com.danrus.utils.PASModelData;
import com.danrus.utils.StringUtils;
import com.danrus.utils.interfaces.ModelWithCape;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_4608;
import net.minecraft.class_548;
import net.minecraft.class_7833;
import net.minecraft.class_9998;

//TODO: поддержка поворота плаща

//? if >=1.21.2 {
public class ASCapeFeatureRenderer extends class_3887<class_9998, class_548> {
    public ASCapeFeatureRenderer(class_3883<class_9998, class_548> context) {
//?} else {
/*public class ASCapeFeatureRenderer extends FeatureRenderer<ArmorStandEntity , ArmorStandArmorEntityModel> {
    public ASCapeFeatureRenderer(FeatureRendererContext<ArmorStandEntity, ArmorStandArmorEntityModel> context) {
*///?}
        super(context);
    }

    //? if >=1.21.2 {
    @Override
    public void render(class_4587 matrixStack, class_4597 vertexConsumers, int light, class_9998 state, float limbAngle, float limbDistance) {
        if (!state.field_53333 && state.field_53464 != null) {
            if (this.method_17165() instanceof ModelWithCape model) {
                var customName = state.field_53464;
                boolean isBaby = state.field_53457;


    //?} else {
    /*@Override
    public void render(MatrixStack matrixStack, VertexConsumerProvider vertexConsumers, int light, ArmorStandEntity entity, float limbAngle, float limbDistance, float tickDelta, float animationProgress, float headYaw, float headPitch) {
        if (!entity.isInvisible() && entity.getCustomName() != null) {
            if (this.getContextModel() instanceof ModelWithCape model) {
                var customName = entity.getCustomName();
                boolean isBaby = entity.isBaby();
    *///?}
                if (customName != null && StringUtils.matchASName(customName.getString()).get(1).contains("C")) {
                    PASModelData modelData = PASModelData.getByName(customName.getString());
                    class_2960 capeTexture = modelData.cape; //TODO: выбор плаща (Name|C:1)

                    matrixStack.method_22903();
                    matrixStack.method_22907(class_7833.field_40714.rotationDegrees(10.0F));
                    matrixStack.method_22907(class_7833.field_40716.rotationDegrees(180F));
                    matrixStack.method_46416(0.0F, 0.02F, -0.12F);
                    //? <=1.21.1 {
                    /*if (isBaby) {
                        matrixStack.translate(0.0F, 0.7F, 0.2F);
                        matrixStack.scale(0.5F, 0.5F, 0.5F);
                    } else {
                        matrixStack.scale(1.0F, 1.0F, 1.0F);
                    }
                    *///?}

                    class_4588 vertexConsumer = vertexConsumers.getBuffer(class_1921.method_23572(capeTexture));
                    model.getCape().field_3665 = true;
                    model.getCape().method_22698(matrixStack, vertexConsumer, light, class_4608.field_21444);

                    matrixStack.method_22909();
                }

            }
        }

    }
}
